#
# spec file for package python-smpplib
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2016-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-smpplib
Version:        2.2.3
Release:        3.3
Summary:        SMPP library for Python
License:        LGPL-2.0-only
URL:            https://pypi.org/project/smpplib/
#Git-Clone:     https://github.com/python-smpplib/python-smpplib.git
Source:         https://github.com/python-smpplib/python-smpplib/archive/%{version}.tar.gz#/smpplib-%{version}.tar.gz
# https://github.com/python-smpplib/python-smpplib/issues/200
Patch0:         python-smpplib-no-mock.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
BuildRequires:  fdupes
Requires:       python-six
BuildArch:      noarch
%python_subpackages

%description
SMPP is the Short Message Peer-to-Peer protocol for conveying SMS
operations.
Python-smpplib is a python based SMPP 3.4 client library that
allows you to send and receive SMS to an SMS gateway or SMSC.

%prep
%autosetup -p1 -n python-smpplib-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
# Remove tests from sitelib
%python_expand rm -R %{buildroot}%{$python_sitelib}/smpplib/tests/
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/smpplib
%{python_sitelib}/smpplib-%{version}.dist-info

%changelog
* Fri Sep 20 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- add sle15_python_module_pythons
* Mon Mar  4 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to autosetup and pyproject macros.
- No more greedy globs in %%files.
* Fri Dec  8 2023 Dirk Müller <dmueller@suse.com>
- update to 2.2.3:
  * Fix: correct UCS2 part length following #184, fixes #216
- update to 2.2.2:
  * Added python 3.10 tests to CircleCI
  * fix socket recv error being silently ignored
  * Refactored Client.read_pdu()
  * Refactored Client.send_pdu()
  * increment sequence of commands as spec (fixes #214)
* Wed May  4 2022 pgajdos@suse.com
- added patches
  fix https://github.com/python-smpplib/python-smpplib/issues/200
  + python-smpplib-no-mock.patch
* Mon Nov 22 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.1
  * Fix: split message detection
* Mon Nov  8 2021 Dirk Müller <dmueller@suse.com>
- add missing six buildrequires
* Mon Oct 25 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.0
  * New: allow customizing how error PDUs are handled
  * New: ignoring unknown optional parameters
  * New: add the option to create TLS/SSL sockets
  * Fix: the max check should include the NULL terminator
  * Fix: not always setting the socket timeout
  * Fix: add mandatory parameters to GenericNack command
  * Fix: handle errors on PDU payload retrieval
- Drop patch:
  * python-smpplib-use-unittest-mock.patch
* Mon Sep  7 2020 Martin Hauke <mardnh@gmx.de>
- Use a more meaningful description
- Add patch:
  * python-smpplib-use-unittest-mock.patch
    Use 'unitest.mock' instead of the external mock package
* Mon Sep  7 2020 Martin Hauke <mardnh@gmx.de>
- Update to release 2.1.0
- Switch to singlespec
- Package cleanup
* Sun Jul 31 2016 mardnh@gmx.de
- Update to version 0.0.0.git1456854982.ee4a653:
  * fix Unknown SMPP command code
* Wed Jan 20 2016 mardnh@gmx.de
- initial package
